<?php

    class Save_Context_To_Metadata_Action extends Reactor_Action
    {
        protected $tpl = 'save_context_to_metadata.php';
        protected $name = 'Save a context variable to metadata';
		
		public static $registration = array(
			ACTION_NAME => 'Save context variable to metadata',
			ACTION_CATEGORY => 'Nagios Reactor',
			ACTION_DESCRIPTION => 'Saves a variable from the current context as a metadata key/value pair.',
			ACTION_AUTHOR => 'Jeremy Yunis, Nagios Enterprises, LLC',
			ACTION_VERSION => '1.0',
			ACTION_DATE => '02/18/2013', //Last version update
			ACTION_AUTHLEVEL => 0,  // 0 - everyone | 1 - Admin only
			ACTION_TYPE => 'core', //core | user. core modules can't be deleted
			ACTION_META => array(),	//Misc information	
		); 
		
        protected $fields = array(
            'context_varname' => array(
                'label' => 'context variable',
                'validate' => 'trim|required|alpha_dash|xss_clean|prep_for_form',
            ),
            'metadata_key' => array(
                'label' => 'metadata key',
                'validate' => 'trim|required|alpha_dash|xss_clean|prep_for_form',
            ),
        );

        public function get_label()
        {
            if($params = $this->get_params()) {
                if(array_key_exists('metadata_key', $params) &&
                        array_key_exists('context_varname', $params)) {
                    return sprintf('Save context variable \'%s\' to metadata key \'%s\'', $params['context_varname'],$params['metadata_key']);
                }
            }
            return parent::get_label();
        }
       
        public function run($context)
        {
            $this->set_context($context);
            $params = $this->get_params();
            if(array_key_exists('metadata_key', $params) &&
                array_key_exists('context_varname', $params)) {
                    $metadata = array(
                        'key' => $params['metadata_key'],
                        'value' => @$context[$params['context_varname']]
                    );
                    $this->ci->metadata_model->create_or_update($metadata);
            }
            $this->set_result(0); 
            return $context;
        }
    }
